==> msn-proxy-0.6.2-pgsql.tar.gz: msn-proxy/msnp15.h <==
/*
 * Copyright (c) 2004, 2005, 2006, 2007, 2008
 *	Luiz Otavio O Souza <loos.br@gmail.com>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * $Id: msnp15.h,v 1.4.2.2 2008/05/17 23:09:25 loos-br Exp $
 */

#include "check-cmd.h"

CMD	SERVER_MSNP15_PRE_CMDS[] = {
		{ "VER", 0, msn_get_ver },
		{ "CVR", 6, check_args },
		{ "XFR", 0, xfr_proxy },
		{ "GCF", 2, check_args },
		{ "USR", 0, server_msnp12_pre_usr },
		{ NULL, 0, NULL }
	};

CMD	SERVER_MSNP15_POST_CMDS[] = {
		{ "XFR", 0, xfr_ns_post_proxy },
		{ NULL, 0, NULL }
	};

CMD	SERVER_MSNP15_CMDS[] = {
		{ "RML", 2, check_args },
		{ "FQY", 2, check_args },
		{ "SBS", 2, check_args },
		{ "MSG", 3, check_args },
		{ "BLP", 2, check_args },
		{ "ADL", 2, check_args },
		{ "CHG", 0, check_ok },
		{ "ILN", 0, msnp13_contact_initial_state },
		{ "UUX", 2, check_args },
		{ "UUN", 2, check_args },
		{ "UBN", 3, check_args },
		{ "UBX", 0, msnp12_ubx },
		{ "URL", 0, msn_url },
		{ "CHL", 2, check_args },
		{ "FLN", 0, msn_contact_logoff },
		{ "QRY", 1, check_args },
		{ "NLN", 0, msnp13_contact_change },
		{ "QNG", 1, check_args },
		{ "XFR", 0, xfr_proxy },
		{ "PRP", 0, msnp12_update_dn },
		{ "RNG", 0, rng_sb_proxy },
		{ "508", 2, check_args },
		{ "241", 2, check_args },
		{ "240", 2, check_args },
		{ "NOT", 1, check_args },
		{ "OUT", 1, check_args },
		{ NULL, 0, NULL }
	};

CMD	CLIENT_MSNP15_PRE_CMDS[] = {
		{ "VER", 0, msn_get_ver },
		{ "OUT", 0, check_ok },
		{ "CVR", 9, check_args },
		{ "USR", 0, client_msn_pre_usr },
		{ NULL, 0, NULL }
	};

CMD	CLIENT_MSNP15_POST_CMDS[] = {
		{ NULL, 0, NULL }
	};

CMD	CLIENT_MSNP15_CMDS[] = {
		{ "CHL", 0, check_ok },
		{ "FQY", 2, check_args },
		{ "RML", 2, check_args },
		{ "BLP", 2, check_args },
		{ "ADL", 0, msnp13_save_contact },
		{ "CHG", 0, msn_update_status },
		{ "UUX", 2, check_args },
		{ "UUM", 5, check_args },
		{ "UUN", 4, check_args },
		{ "URL", 0, msn_url },
		{ "PNG", 0, check_ok },
		{ "QRY", 3, check_args },
		{ "XFR", 2, check_args },
		{ "PRP", 3, check_args },
		{ "OUT", 0, check_ok },
		{ NULL, 0, NULL }
	};

SBCMD	SERVER_MSNP15_SB_CMDS[] = {
		{ "USR", 4, check_sb_args },
		{ "CAL", 3, check_sb_args },
		{ "IRO", 0, sb_iro },
		{ "JOI", 0, msn_sb_joi },
		{ "ACK", 1, check_sb_args },
		{ "MSG", 0, msn_sb_server_msg },
		{ "BYE", 1, check_sb_args },
		{ "ANS", 2, check_sb_args },
		{ NULL, 0, NULL }
	};

SBCMD	SERVER_MSNP15_SB_POST_CMDS[] = {
		{ "BYE", 0, msn_sb_post_bye },
		{ NULL, 0, NULL }
	};

SBCMD	CLIENT_MSNP15_SB_CMDS[] = {
		{ "USR", 3, check_sb_args },
		{ "CAL", 0, msn_sb_cal },
		{ "ANS", 4, check_sb_args },
		{ "OUT", 0, check_sb_args },
		{ "MSG", 0, msn_sb_client_msg },
		{ NULL, 0, NULL }
	};

SBCMD	CLIENT_MSNP15_SB_POST_CMDS[] = {
		{ "OUT", 0, msn_sb_post_out },
		{ NULL, 0, NULL }
	};

CMDS_	MSNP15_CMDS[] = {
	{ SERVER_CMD,		"server_cmd",		SERVER_MSNP15_CMDS },
	{ SERVER_PRE_CMD,	"server_pre_cmd",	SERVER_MSNP15_PRE_CMDS },
	{ SERVER_POST_CMD,	"server_post_cmd",	SERVER_MSNP15_POST_CMDS },
	{ CLIENT_CMD,		"client_cmd",		CLIENT_MSNP15_CMDS },
	{ CLIENT_PRE_CMD,	"client_pre_cmd",	CLIENT_MSNP15_PRE_CMDS },
	{ CLIENT_POST_CMD,	"client_post_cmd",	CLIENT_MSNP15_POST_CMDS },
	{ 0, NULL, NULL }
	};

SBCMDS_	MSNP15_SBCMDS[] = {
	{ SERVER_SB_CMD,	"sever_sb_cmd",		SERVER_MSNP15_SB_CMDS },
	{ SERVER_SB_POST_CMD,	"server_sb_post_cmd",	SERVER_MSNP15_SB_POST_CMDS },
	{ CLIENT_SB_CMD,	"client_sb_cmd",	CLIENT_MSNP15_SB_CMDS },
	{ CLIENT_SB_POST_CMD,	"client_sb_post_cmd",	CLIENT_MSNP15_SB_POST_CMDS },
	{ 0, NULL, NULL }
	};

==> msn-proxy-0.6.3-pgsql.tar.gz: msn-proxy/msnp15.h <==
/*
 * Copyright (c) 2004, 2005, 2006, 2007, 2008
 *	Luiz Otavio O Souza <loos.br@gmail.com>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * $Id: msnp15.h,v 1.4.2.4 2008/10/16 00:40:38 loos-br Exp $
 */

#include "check-cmd.h"

CMD	SERVER_MSNP15_PRE_CMDS[] = {
		{ "CVR", 6, check_args },
		{ "GCF", 2, check_args },
		{ "USR", 0, server_msnp12_pre_usr },
		{ "VER", 0, msn_get_ver },
		{ "XFR", 0, xfr_proxy },
		{ NULL, 0, NULL }
	};

CMD	SERVER_MSNP15_POST_CMDS[] = {
		{ "XFR", 0, xfr_ns_post_proxy },
		{ NULL, 0, NULL }
	};

CMD	SERVER_MSNP15_CMDS[] = {
		{ "241", 2, check_args },
		{ "508", 2, check_args },
		{ "509", 2, check_args },
		{ "ADL", 2, check_args },
		{ "BLP", 2, check_args },
		{ "CHG", 0, check_ok },
		{ "CHL", 2, check_args },
		{ "FLN", 0, msn_contact_logoff },
		{ "FQY", 2, check_args },
		{ "ILN", 0, msnp13_contact_initial_state },
		{ "MSG", 3, check_args },
		{ "NLN", 0, msnp13_contact_change },
		{ "NOT", 1, check_args },
		{ "OUT", 1, check_args },
		{ "PRP", 0, msnp12_update_dn },
		{ "QNG", 1, check_args },
		{ "QRY", 1, check_args },
		{ "RML", 2, check_args },
		{ "RNG", 0, rng_sb_proxy },
		{ "SBS", 2, check_args },
		{ "UBN", 3, check_args },
		{ "UBX", 0, msnp12_ubx },
		{ "URL", 0, msn_url },
		{ "USR", 5, check_args },
		{ "UUX", 2, check_args },
		{ "UUN", 2, check_args },
		{ "XFR", 0, xfr_proxy },
		{ NULL, 0, NULL }
	};

CMD	CLIENT_MSNP15_PRE_CMDS[] = {
		{ "CVR", 9, check_args },
		{ "OUT", 0, check_ok },
		{ "USR", 0, client_msn_pre_usr },
		{ "VER", 0, msn_get_ver },
		{ NULL, 0, NULL }
	};

CMD	CLIENT_MSNP15_POST_CMDS[] = {
		{ NULL, 0, NULL }
	};

CMD	CLIENT_MSNP15_CMDS[] = {
		{ "ADL", 0, msnp13_save_contact },
		{ "BLP", 2, check_args },
		{ "CHG", 0, msn_update_status },
		{ "CHL", 0, check_ok },
		{ "FQY", 2, check_args },
		{ "OUT", 0, check_ok },
		{ "PNG", 0, check_ok },
		{ "PRP", 3, check_args },
		{ "QRY", 3, check_args },
		{ "RML", 2, check_args },
		{ "URL", 0, msn_url },
		{ "USR", 4, check_args },
		{ "UUM", 5, check_args },
		{ "UUN", 4, check_args },
		{ "UUX", 2, check_args },
		{ "XFR", 2, check_args },
		{ NULL, 0, NULL }
	};

SBCMD	SERVER_MSNP15_SB_CMDS[] = {
		{ "ACK", 1, check_sb_args },
		{ "ANS", 2, check_sb_args },
		{ "BYE", 1, check_sb_args },
		{ "CAL", 3, check_sb_args },
		{ "IRO", 0, sb_iro },
		{ "JOI", 0, msn_sb_joi },
		{ "MSG", 0, msn_sb_server_msg },
		{ "USR", 4, check_sb_args },
		{ NULL, 0, NULL }
	};

SBCMD	SERVER_MSNP15_SB_POST_CMDS[] = {
		{ "BYE", 0, msn_sb_post_bye },
		{ NULL, 0, NULL }
	};

SBCMD	CLIENT_MSNP15_SB_CMDS[] = {
		{ "ANS", 4, check_sb_args },
		{ "CAL", 0, msn_sb_cal },
		{ "MSG", 0, msn_sb_client_msg },
		{ "OUT", 0, check_sb_args },
		{ "USR", 3, check_sb_args },
		{ NULL, 0, NULL }
	};

SBCMD	CLIENT_MSNP15_SB_POST_CMDS[] = {
		{ "OUT", 0, msn_sb_post_out },
		{ NULL, 0, NULL }
	};

CMDS_	MSNP15_CMDS[] = {
	{ SERVER_CMD,		"server_cmd",		SERVER_MSNP15_CMDS },
	{ SERVER_PRE_CMD,	"server_pre_cmd",	SERVER_MSNP15_PRE_CMDS },
	{ SERVER_POST_CMD,	"server_post_cmd",	SERVER_MSNP15_POST_CMDS },
	{ CLIENT_CMD,		"client_cmd",		CLIENT_MSNP15_CMDS },
	{ CLIENT_PRE_CMD,	"client_pre_cmd",	CLIENT_MSNP15_PRE_CMDS },
	{ CLIENT_POST_CMD,	"client_post_cmd",	CLIENT_MSNP15_POST_CMDS },
	{ 0, NULL, NULL }
	};

SBCMDS_	MSNP15_SBCMDS[] = {
	{ SERVER_SB_CMD,	"sever_sb_cmd",		SERVER_MSNP15_SB_CMDS },
	{ SERVER_SB_POST_CMD,	"server_sb_post_cmd",	SERVER_MSNP15_SB_POST_CMDS },
	{ CLIENT_SB_CMD,	"client_sb_cmd",	CLIENT_MSNP15_SB_CMDS },
	{ CLIENT_SB_POST_CMD,	"client_sb_post_cmd",	CLIENT_MSNP15_SB_POST_CMDS },
	{ 0, NULL, NULL }
	};
